"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var handler_1 = require("../handler");
var fakecontext_1 = require("./fakecontext");
var fakegithub_1 = require("./fakegithub");
it("adds needs-area label to pull request when a label doesn't match area:.* on the pull request", function () {
    expect.assertions(1);
    var github = new fakegithub_1.FakeGithub([], "pull_request");
    var context = new fakecontext_1.FakeContext({ pull_request: { labels: [] } }, github, {});
    return handler_1.handle(context, [{ missingLabel: "needs-area", regex: "area:.*" }], 1).then(function (resp) {
        expect(github.labels).toContain("needs-area");
    });
});
it("doesn't add needs-area label to the pull request when needs-area label is already on the pull request", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub(["needs-area"], "pull_request");
    var context = new fakecontext_1.FakeContext({ pull_request: { labels: [] } }, github, {});
    return handler_1.handle(context, [{ missingLabel: "needs-area", regex: "area:.*" }], 1).then(function (resp) {
        expect(github.labels).toEqual(["needs-area"]);
        expect(github.labelsAdded).toEqual([]);
    });
});
it("doesn't add needs-area label to the pull request when a label matching area/.* is on the pull request", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub(["area:test"], "pull_request");
    var context = new fakecontext_1.FakeContext({ pull_request: { labels: [] } }, github, {});
    return handler_1.handle(context, [{ missingLabel: "needs-area", regex: "area:.*" }], 1).then(function (resp) {
        expect(github.labels).toEqual(["area:test"]);
        expect(github.labelsAdded).toEqual([]);
    });
});
it("removes needs-area label on the pull request when a label matching area/.* exists on the pull request", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub(["area:test", "needs-area"], "pull_request");
    var context = new fakecontext_1.FakeContext({ pull_request: { labels: [], label: "area:test" } }, github, {});
    return handler_1.handle(context, [{ missingLabel: "needs-area", regex: "area:.*" }], 1).then(function (resp) {
        expect(github.labels).toEqual(["area:test"]);
        expect(github.labelsRemoved).toEqual(["needs-area"]);
    });
});
it("doesn't remove needs-area label on then pull request when a label doesn't match area/.* on the pull request", function () {
    expect.assertions(2);
    var github = new fakegithub_1.FakeGithub(["test:test", "needs-area"], "pull_request");
    var context = new fakecontext_1.FakeContext({ pull_request: { labels: [], label: "test:test" } }, github, {});
    return handler_1.handle(context, [{ missingLabel: "needs-area", regex: "area:.*" }], 1).then(function (resp) {
        expect(github.labels).toEqual(["test:test", "needs-area"]);
        expect(github.labelsRemoved).toEqual([]);
    });
});
//# sourceMappingURL=handler.pulls.test.js.map